django-memoize
==============

**django-memoize** is an implementation
of `memoization <http://en.wikipedia.org/wiki/Memoization>`_ technique
for Django. You can think of it as a cache for function or method results.


Documentation
-------------

Documentation is available at http://pythonhosted.org/django-memoize/.
